@@ -61,10 +61,12 @@ void bli_syrk_front
 	bli_obj_alias_to( a, &at_local );
 	bli_obj_induce_trans( &at_local );
 
+#if 0
 #ifdef BLIS_ENABLE_SMALL_MATRIX
 	gint_t status = bli_syrk_small( alpha, &a_local, &at_local, beta, &c_local,
 	                                cntx, cntl );
 	if ( status == BLIS_SUCCESS ) return;
+#endif
 #endif
 
 	// Check parameters.
@@ -105,19 +107,11 @@ void bli_syrk_front
 	// bli_l3_cntl_create_if()). This allows us to access the schemas from
 	// the control tree, which hopefully reduces some confusion, particularly
 	// in bli_packm_init().
-	if ( bli_cntx_method( cntx ) == BLIS_NAT )
-	{
-		bli_obj_set_pack_schema( BLIS_PACKED_ROW_PANELS, &a_local );
-		bli_obj_set_pack_schema( BLIS_PACKED_COL_PANELS, &at_local );
-	}
-	else // if ( bli_cntx_method( cntx ) != BLIS_NAT )
-	{
-		pack_t schema_a = bli_cntx_schema_a_block( cntx );
-		pack_t schema_b = bli_cntx_schema_b_panel( cntx );
+	pack_t schema_a = bli_cntx_schema_a_block( cntx );
+	pack_t schema_b = bli_cntx_schema_b_panel( cntx );
 
-		bli_obj_set_pack_schema( schema_a, &a_local );
-		bli_obj_set_pack_schema( schema_b, &at_local );
-	}
+	bli_obj_set_pack_schema( schema_a, &a_local );
+	bli_obj_set_pack_schema( schema_b, &at_local );
 
 	// Invoke the internal back-end.
 	bli_l3_thread_decorator
