@@ -104,6 +104,7 @@ static char bli_error_string[BLIS_MAX_NUM_ERR_MSGS][BLIS_MAX_ERR_MSG_LENGTH] =
 	[-BLIS_EXPECTED_OBJECT_ALIAS]                = "Expected object to be alias.",
 
 	[-BLIS_INVALID_ARCH_ID]                      = "Invalid architecture id value.",
+	[-BLIS_UNINITIALIZED_GKS_CNTX]               = "Accessed uninitialized context in gks; BLIS_ARCH_TYPE is probably set to an invalid architecture id.",
 
 	[-BLIS_MC_DEF_NONMULTIPLE_OF_MR]             = "Default MC is non-multiple of MR for one or more datatypes.",
 	[-BLIS_MC_MAX_NONMULTIPLE_OF_MR]             = "Maximum MC is non-multiple of MR for one or more datatypes.",
@@ -163,7 +164,7 @@ void bli_error_checking_level_set( errlev_t new_level )
 	bli_pthread_mutex_unlock( &err_mutex );
 }
 
-bool_t bli_error_checking_is_enabled( void )
+bool bli_error_checking_is_enabled( void )
 {
 	return bli_error_checking_level() != BLIS_NO_ERROR_CHECKING;
 }
