@@ -36,10 +36,10 @@
 BLIS_EXPORT_BLIS errlev_t bli_error_checking_level( void );
 BLIS_EXPORT_BLIS void     bli_error_checking_level_set( errlev_t new_level );
 
-BLIS_EXPORT_BLIS bool_t    bli_error_checking_is_enabled( void );
+BLIS_EXPORT_BLIS bool     bli_error_checking_is_enabled( void );
 
-void      bli_print_msg( char* str, char* file, guint_t line );
-void      bli_abort( void );
+void                      bli_print_msg( char* str, char* file, guint_t line );
+BLIS_EXPORT_BLIS void     bli_abort( void );
 
-char*     bli_error_string_for_code( gint_t code );
+char*                     bli_error_string_for_code( gint_t code );
 
