@@ -34,6 +34,7 @@
 
 #include "blis.h"
 
+#ifdef BLIS_ENABLE_BLAS
 
 //
 // Define BLAS-to-BLIS interfaces.
@@ -85,8 +86,66 @@ ftype PASTEF772(ch,blasname,chc) \
 	return rho; \
 }
 
-#ifdef BLIS_ENABLE_BLAS
-INSERT_GENTFUNCDOT_BLAS( dot, dotv )
+INSERT_GENTFUNCDOTR_BLAS( dot, dotv )
+
+#ifdef BLIS_DISABLE_COMPLEX_RETURN_INTEL
+
+INSERT_GENTFUNCDOTC_BLAS( dot, dotv )
+
+#else
+
+// For the "intel" complex return type, use a hidden parameter to return the result
+#undef  GENTFUNCDOT
+#define GENTFUNCDOT( ftype, ch, chc, blis_conjx, blasname, blisname ) \
+\
+void PASTEF772(ch,blasname,chc) \
+     ( \
+       ftype*         rhop, \
+       const f77_int* n, \
+       const ftype*   x, const f77_int* incx, \
+       const ftype*   y, const f77_int* incy  \
+     ) \
+{ \
+	dim_t  n0; \
+	ftype* x0; \
+	ftype* y0; \
+	inc_t  incx0; \
+	inc_t  incy0; \
+	ftype  rho; \
+\
+	/* Initialize BLIS. */ \
+	bli_init_auto(); \
+\
+	/* Convert/typecast negative values of n to zero. */ \
+	bli_convert_blas_dim1( *n, n0 ); \
+\
+	/* If the input increments are negative, adjust the pointers so we can
+	   use positive increments instead. */ \
+	bli_convert_blas_incv( n0, (ftype*)x, *incx, x0, incx0 ); \
+	bli_convert_blas_incv( n0, (ftype*)y, *incy, y0, incy0 ); \
+\
+	/* Call BLIS interface. */ \
+	PASTEMAC2(ch,blisname,BLIS_TAPI_EX_SUF) \
+	( \
+	  blis_conjx, \
+	  BLIS_NO_CONJUGATE, \
+	  n0, \
+	  x0, incx0, \
+	  y0, incy0, \
+	  &rho, \
+	  NULL, \
+	  NULL  \
+	); \
+\
+	/* Finalize BLIS. */ \
+	bli_finalize_auto(); \
+\
+	*rhop = rho; \
+}
+
+INSERT_GENTFUNCDOTC_BLAS( dot, dotv )
+
+#endif
 
 
 // -- "Black sheep" dot product function definitions --
