@@ -379,8 +379,13 @@ void bli_sgemmtrsm_u_haswell_asm_6x16
 	
 	vbroadcastss(mem(5+5*6)*4(rax), ymm0) // ymm0 = (1/alpha55)
 	
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
 	vmulps(ymm0, ymm14, ymm14) // ymm14 *= (1/alpha55)
 	vmulps(ymm0, ymm15, ymm15) // ymm15 *= (1/alpha55)
+#else
+	vdivps(ymm0, ymm14, ymm14) // ymm14 /= alpha55
+	vdivps(ymm0, ymm15, ymm15) // ymm15 /= alpha55
+#endif
 	
 	vmovups(ymm14, mem(rcx)) // store ( beta50..beta57 ) = ymm14
 	vmovups(ymm15, mem(rdx)) // store ( beta58..beta5F ) = ymm15
@@ -398,8 +403,13 @@ void bli_sgemmtrsm_u_haswell_asm_6x16
 	vsubps(ymm2, ymm12, ymm12) // ymm12 -= ymm2
 	vsubps(ymm3, ymm13, ymm13) // ymm13 -= ymm3
 	
-	vmulps(ymm12, ymm1, ymm12) // ymm12 *= (1/alpha44)
-	vmulps(ymm13, ymm1, ymm13) // ymm13 *= (1/alpha44)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulps(ymm1, ymm12, ymm12) // ymm12 *= (1/alpha44)
+	vmulps(ymm1, ymm13, ymm13) // ymm13 *= (1/alpha44)
+#else
+	vdivps(ymm1, ymm12, ymm12) // ymm12 /= alpha44
+	vdivps(ymm1, ymm13, ymm13) // ymm13 /= alpha44
+#endif
 	
 	vmovups(ymm12, mem(rcx)) // store ( beta40..beta47 ) = ymm12
 	vmovups(ymm13, mem(rdx)) // store ( beta48..beta4F ) = ymm13
@@ -422,8 +432,13 @@ void bli_sgemmtrsm_u_haswell_asm_6x16
 	vsubps(ymm2, ymm10, ymm10) // ymm10 -= ymm2
 	vsubps(ymm3, ymm11, ymm11) // ymm11 -= ymm3
 	
-	vmulps(ymm10, ymm0, ymm10) // ymm10 *= (1/alpha33)
-	vmulps(ymm11, ymm0, ymm11) // ymm11 *= (1/alpha33)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulps(ymm0, ymm10, ymm10) // ymm10 *= (1/alpha33)
+	vmulps(ymm0, ymm11, ymm11) // ymm11 *= (1/alpha33)
+#else
+	vdivps(ymm0, ymm10, ymm10) // ymm10 /= alpha33
+	vdivps(ymm0, ymm11, ymm11) // ymm11 /= alpha33
+#endif
 	
 	vmovups(ymm10, mem(rcx)) // store ( beta30..beta37 ) = ymm10
 	vmovups(ymm11, mem(rdx)) // store ( beta38..beta3F ) = ymm11
@@ -451,8 +466,13 @@ void bli_sgemmtrsm_u_haswell_asm_6x16
 	vsubps(ymm2, ymm8, ymm8) // ymm8 -= ymm2
 	vsubps(ymm3, ymm9, ymm9) // ymm9 -= ymm3
 	
-	vmulps(ymm8, ymm1, ymm8) // ymm8 *= (1/alpha33)
-	vmulps(ymm9, ymm1, ymm9) // ymm9 *= (1/alpha33)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulps(ymm1, ymm8, ymm8) // ymm8 *= (1/alpha22)
+	vmulps(ymm1, ymm9, ymm9) // ymm9 *= (1/alpha22)
+#else
+	vdivps(ymm1, ymm8, ymm8) // ymm8 /= alpha22
+	vdivps(ymm1, ymm9, ymm9) // ymm9 /= alpha22
+#endif
 	
 	vmovups(ymm8, mem(rcx)) // store ( beta20..beta27 ) = ymm8
 	vmovups(ymm9, mem(rdx)) // store ( beta28..beta2F ) = ymm9
@@ -485,8 +505,13 @@ void bli_sgemmtrsm_u_haswell_asm_6x16
 	vsubps(ymm2, ymm6, ymm6) // ymm6 -= ymm2
 	vsubps(ymm3, ymm7, ymm7) // ymm7 -= ymm3
 	
-	vmulps(ymm6, ymm0, ymm6) // ymm6 *= (1/alpha44)
-	vmulps(ymm7, ymm0, ymm7) // ymm7 *= (1/alpha44)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulps(ymm0, ymm6, ymm6) // ymm6 *= (1/alpha11)
+	vmulps(ymm0, ymm7, ymm7) // ymm7 *= (1/alpha11)
+#else
+	vdivps(ymm0, ymm6, ymm6) // ymm6 /= alpha11
+	vdivps(ymm0, ymm7, ymm7) // ymm7 /= alpha11
+#endif
 	
 	vmovups(ymm6, mem(rcx)) // store ( beta10..beta17 ) = ymm6
 	vmovups(ymm7, mem(rdx)) // store ( beta18..beta1F ) = ymm7
@@ -524,8 +549,13 @@ void bli_sgemmtrsm_u_haswell_asm_6x16
 	vsubps(ymm2, ymm4, ymm4) // ymm4 -= ymm2
 	vsubps(ymm3, ymm5, ymm5) // ymm5 -= ymm3
 	
-	vmulps(ymm4, ymm1, ymm4) // ymm4 *= (1/alpha00)
-	vmulps(ymm5, ymm1, ymm5) // ymm5 *= (1/alpha00)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulps(ymm1, ymm4, ymm4) // ymm4 *= (1/alpha00)
+	vmulps(ymm1, ymm5, ymm5) // ymm5 *= (1/alpha00)
+#else
+	vdivps(ymm1, ymm4, ymm4) // ymm4 /= alpha00
+	vdivps(ymm1, ymm5, ymm5) // ymm5 /= alpha00
+#endif
 	
 	vmovups(ymm4, mem(rcx)) // store ( beta00..beta07 ) = ymm4
 	vmovups(ymm5, mem(rdx)) // store ( beta08..beta0F ) = ymm5
@@ -1138,8 +1168,13 @@ void bli_dgemmtrsm_u_haswell_asm_6x8
 	
 	vbroadcastsd(mem(5+5*6)*8(rax), ymm0) // ymm0 = (1/alpha55)
 	
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
 	vmulpd(ymm0, ymm14, ymm14) // ymm14 *= (1/alpha55)
 	vmulpd(ymm0, ymm15, ymm15) // ymm15 *= (1/alpha55)
+#else
+	vdivpd(ymm0, ymm14, ymm14) // ymm14 /= alpha55
+	vdivpd(ymm0, ymm15, ymm15) // ymm15 /= alpha55
+#endif
 	
 	vmovupd(ymm14, mem(rcx)) // store ( beta50..beta53 ) = ymm14
 	vmovupd(ymm15, mem(rdx)) // store ( beta54..beta57 ) = ymm15
@@ -1157,8 +1192,13 @@ void bli_dgemmtrsm_u_haswell_asm_6x8
 	vsubpd(ymm2, ymm12, ymm12) // ymm12 -= ymm2
 	vsubpd(ymm3, ymm13, ymm13) // ymm13 -= ymm3
 	
-	vmulpd(ymm12, ymm1, ymm12) // ymm12 *= (1/alpha44)
-	vmulpd(ymm13, ymm1, ymm13) // ymm13 *= (1/alpha44)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulpd(ymm1, ymm12, ymm12) // ymm12 *= (1/alpha44)
+	vmulpd(ymm1, ymm13, ymm13) // ymm13 *= (1/alpha44)
+#else
+	vdivpd(ymm1, ymm12, ymm12) // ymm12 /= alpha44
+	vdivpd(ymm1, ymm13, ymm13) // ymm13 /= alpha44
+#endif
 	
 	vmovupd(ymm12, mem(rcx)) // store ( beta40..beta43 ) = ymm12
 	vmovupd(ymm13, mem(rdx)) // store ( beta44..beta47 ) = ymm13
@@ -1181,8 +1221,13 @@ void bli_dgemmtrsm_u_haswell_asm_6x8
 	vsubpd(ymm2, ymm10, ymm10) // ymm10 -= ymm2
 	vsubpd(ymm3, ymm11, ymm11) // ymm11 -= ymm3
 	
-	vmulpd(ymm10, ymm0, ymm10) // ymm10 *= (1/alpha33)
-	vmulpd(ymm11, ymm0, ymm11) // ymm11 *= (1/alpha33)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulpd(ymm0, ymm10, ymm10) // ymm10 *= (1/alpha33)
+	vmulpd(ymm0, ymm11, ymm11) // ymm11 *= (1/alpha33)
+#else
+	vdivpd(ymm0, ymm10, ymm10) // ymm10 /= alpha33
+	vdivpd(ymm0, ymm11, ymm11) // ymm11 /= alpha33
+#endif
 	
 	vmovupd(ymm10, mem(rcx)) // store ( beta30..beta33 ) = ymm10
 	vmovupd(ymm11, mem(rdx)) // store ( beta34..beta37 ) = ymm11
@@ -1210,8 +1255,13 @@ void bli_dgemmtrsm_u_haswell_asm_6x8
 	vsubpd(ymm2, ymm8, ymm8) // ymm8 -= ymm2
 	vsubpd(ymm3, ymm9, ymm9) // ymm9 -= ymm3
 	
-	vmulpd(ymm8, ymm1, ymm8) // ymm8 *= (1/alpha33)
-	vmulpd(ymm9, ymm1, ymm9) // ymm9 *= (1/alpha33)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulpd(ymm1, ymm8, ymm8) // ymm8 *= (1/alpha22)
+	vmulpd(ymm1, ymm9, ymm9) // ymm9 *= (1/alpha22)
+#else
+	vdivpd(ymm1, ymm8, ymm8) // ymm8 /= alpha22
+	vdivpd(ymm1, ymm9, ymm9) // ymm9 /= alpha22
+#endif
 	
 	vmovupd(ymm8, mem(rcx)) // store ( beta20..beta23 ) = ymm8
 	vmovupd(ymm9, mem(rdx)) // store ( beta24..beta27 ) = ymm9
@@ -1244,8 +1294,13 @@ void bli_dgemmtrsm_u_haswell_asm_6x8
 	vsubpd(ymm2, ymm6, ymm6) // ymm6 -= ymm2
 	vsubpd(ymm3, ymm7, ymm7) // ymm7 -= ymm3
 	
-	vmulpd(ymm6, ymm0, ymm6) // ymm6 *= (1/alpha44)
-	vmulpd(ymm7, ymm0, ymm7) // ymm7 *= (1/alpha44)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulpd(ymm0, ymm6, ymm6) // ymm6 *= (1/alpha11)
+	vmulpd(ymm0, ymm7, ymm7) // ymm7 *= (1/alpha11)
+#else
+	vdivpd(ymm0, ymm6, ymm6) // ymm6 /= alpha11
+	vdivpd(ymm0, ymm7, ymm7) // ymm7 /= alpha11
+#endif
 	
 	vmovupd(ymm6, mem(rcx)) // store ( beta10..beta13 ) = ymm6
 	vmovupd(ymm7, mem(rdx)) // store ( beta14..beta17 ) = ymm7
@@ -1283,8 +1338,13 @@ void bli_dgemmtrsm_u_haswell_asm_6x8
 	vsubpd(ymm2, ymm4, ymm4) // ymm4 -= ymm2
 	vsubpd(ymm3, ymm5, ymm5) // ymm5 -= ymm3
 	
-	vmulpd(ymm4, ymm1, ymm4) // ymm4 *= (1/alpha00)
-	vmulpd(ymm5, ymm1, ymm5) // ymm5 *= (1/alpha00)
+#ifdef BLIS_ENABLE_TRSM_PREINVERSION
+	vmulpd(ymm1, ymm4, ymm4) // ymm4 *= (1/alpha00)
+	vmulpd(ymm1, ymm5, ymm5) // ymm5 *= (1/alpha00)
+#else
+	vdivpd(ymm1, ymm4, ymm4) // ymm4 /= alpha00
+	vdivpd(ymm1, ymm5, ymm5) // ymm5 /= alpha00
+#endif
 	
 	vmovupd(ymm4, mem(rcx)) // store ( beta00..beta03 ) = ymm4
 	vmovupd(ymm5, mem(rdx)) // store ( beta04..beta07 ) = ymm5
